==> libnetconf-0.9.1.tar.gz: libnetconf/doc/doxygen/html/da/d1b/usage.js <==
var usage =
[
    [ "GLOSSARY", "da/d1b/usage.html#usage-glossary", null ],
    [ "Client", "d1/d25/client.html", [
      [ "Client Workflow", "d1/d25/client.html#client-workflow", null ]
    ] ],
    [ "Server", "da/db3/server.html", [
      [ "Server Architecture", "da/db3/server.html#server-arch", [
        [ "Single-level Architecture", "da/db3/server.html#server-arch-singlelevel", null ],
        [ "Multi-level Architecture", "da/db3/server.html#server-arch-multilevel", null ]
      ] ],
      [ "Server Workflow", "da/db3/server.html#server-workflow", null ]
    ] ],
    [ "Transport Protocol", "d4/d76/transport.html", [
      [ "Transport Support on the Client Side", "d4/d76/transport.html#transport-client", null ],
      [ "Transport Support on the Server Side", "d4/d76/transport.html#transport-server", null ]
    ] ],
    [ "Call Home", "da/d4e/callhome.html", [
      [ "Call Home on the Client Side", "da/d4e/callhome.html#callhome-client", null ],
      [ "Call Home on the Server Side", "da/d4e/callhome.html#callhome-server", null ],
      [ "Call Home workflow in libnetconf", "da/d4e/callhome.html#callhome-workflow", null ]
    ] ],
    [ "Datastores Usage", "d1/deb/datastores.html", null ],
    [ "Data Validation", "db/df0/validation.html", null ],
    [ "Miscelaneous", "d8/d0b/misc.html", [
      [ "Date and Time", "d8/d0b/misc.html#misc-datetime", null ],
      [ "NETCONF Errors Handling", "d8/d0b/misc.html#misc-errors", null ],
      [ "Logging Messages", "d8/d0b/misc.html#misc-logging", null ]
    ] ],
    [ "Troubleshooting", "d7/dc8/troubles.html", null ]
];

==> libnetconf-0.10.0.tar.gz: libnetconf/doc/doxygen/html/da/d1b/usage.js <==
var usage =
[
    [ "GLOSSARY", "da/d1b/usage.html#usage-glossary", null ],
    [ "Client", "d1/d25/client.html", [
      [ "Client Workflow", "d1/d25/client.html#client-workflow", null ]
    ] ],
    [ "Server", "da/db3/server.html", [
      [ "Server Architecture", "da/db3/server.html#server-arch", [
        [ "Single-level Architecture", "da/db3/server.html#server-arch-singlelevel", null ],
        [ "Multi-level Architecture", "da/db3/server.html#server-arch-multilevel", null ],
        [ "Integrated Architecture", "da/db3/server.html#server-arch-integrated", null ]
      ] ],
      [ "Server Workflow", "da/db3/server.html#server-workflow", null ]
    ] ],
    [ "Transport Protocol", "d4/d76/transport.html", [
      [ "Transport Support on the Client Side", "d4/d76/transport.html#transport-client", null ],
      [ "Transport Support on the Server Side", "d4/d76/transport.html#transport-server", null ]
    ] ],
    [ "Call Home", "da/d4e/callhome.html", [
      [ "Call Home on the Client Side", "da/d4e/callhome.html#callhome-client", null ],
      [ "Call Home on the Server Side", "da/d4e/callhome.html#callhome-server", null ],
      [ "Call Home workflow in libnetconf", "da/d4e/callhome.html#callhome-workflow", null ]
    ] ],
    [ "Datastores Usage", "d1/deb/datastores.html", null ],
    [ "Data Validation", "db/df0/validation.html", null ],
    [ "Miscelaneous", "d8/d0b/misc.html", [
      [ "Date and Time", "d8/d0b/misc.html#misc-datetime", null ],
      [ "NETCONF Errors Handling", "d8/d0b/misc.html#misc-errors", null ],
      [ "Logging Messages", "d8/d0b/misc.html#misc-logging", null ]
    ] ],
    [ "Troubleshooting", "d7/dc8/troubles.html", null ]
];
